@@ -28,13 +28,18 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: fuse.h,v 1.3.2.5 2008/07/18 20:32:14 arcanum Exp $ */
+/* $Id: fuse.h 2107 2010-03-20 18:00:47Z arcanum $ */
 
 /* avr/fuse.h - Fuse API */
 
 #ifndef _AVR_FUSE_H_
 #define _AVR_FUSE_H_ 1
 
+/* This file must be explicitly included by <avr/io.h>. */
+#if !defined(_AVR_IO_H_)
+#error "You must #include <avr/io.h> and not <avr/fuse.h> by itself."
+#endif
+
 
 /** \file */
 /** \defgroup avr_fuse <avr/fuse.h>: Fuse Support
@@ -255,10 +260,15 @@ typedef struct
 
 #endif
 
-#ifndef FUSES
-#define FUSES __fuse_t __fuse FUSEMEM
+#if !defined(FUSES)
+  #if defined(__AVR_XMEGA__)
+    #define FUSES NVM_FUSES_t __fuse FUSEMEM
+  #else
+    #define FUSES __fuse_t __fuse FUSEMEM
+  #endif
 #endif
 
+
 #endif /* !__ASSEMBLER__ */
 
 #endif /* _AVR_FUSE_H_ */
