@@ -1,4 +1,4 @@
-/* Copyright (c) 2005, Anatoly Sokolov
+/* Copyright (c) 2005,2007 Anatoly Sokolov
    All rights reserved.
 
    Redistribution and use in source and binary forms, with or without
@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iotnx5.h,v 1.4.2.1 2006/01/31 21:11:44 aesok Exp $ */
+/* $Id: iotnx5.h 2269 2011-12-29 08:07:25Z joerg_wunsch $ */
 
 /* avr/iotnx5.h - definitions for ATtiny25, ATtiny45 and ATtiny85 */
 
@@ -233,8 +233,6 @@
 #define CLKPS0  0
 
 #define PLLCSR  _SFR_IO8(0x27)
-/* The register summary calls this bit SM, but the register
- * description and the XML files call it LSM for low-speed mode.*/
 #define LSM     7
 #define PCKE    2
 #define PLLE    1
@@ -299,16 +297,19 @@
 #define PORF    0
 
 #define MCUCR   _SFR_IO8(0x35)
+#define BODS    7
 #define PUD     6
 #define SE      5
 #define SM1     4
 #define SM0     3
+#define BODSE   2
 #define ISC01   1
 #define ISC00   0
 
 /* Reserved [0x36] */
 
 #define SPMCSR  _SFR_IO8(0x37)
+#define RSIG    5
 #define CTPB    4
 #define RFLB    3
 #define PGWRT   2
@@ -349,58 +350,84 @@
 /* Interrupt vectors */
 /* Interrupt vector 0 is the reset vector. */
 /* External Interrupt 0 */
-#define INT0_vect			_VECTOR(1)
+#define INT0_vect_num	        1
+#define INT0_vect			    _VECTOR(1)
 #define SIG_INTERRUPT0			_VECTOR(1)
 
 /* Pin change Interrupt Request 0 */
-#define PCINT0_vect			_VECTOR(2)
+#define PCINT0_vect_num			2
+#define PCINT0_vect			    _VECTOR(2)
 #define SIG_PIN_CHANGE			_VECTOR(2)
 
 /* Timer/Counter1 Compare Match 1A */
+#define TIM1_COMPA_vect_num		3
 #define TIM1_COMPA_vect			_VECTOR(3)
-#define SIG_OUTPUT_COMPARE1A		_VECTOR(3)
+#define TIMER1_COMPA_vect_num	3
+#define TIMER1_COMPA_vect		_VECTOR(3)
+#define SIG_OUTPUT_COMPARE1A	_VECTOR(3)
 
 /* Timer/Counter1 Overflow */
+#define TIM1_OVF_vect_num		4
 #define TIM1_OVF_vect			_VECTOR(4)
+#define TIMER1_OVF_vect_num		4
+#define TIMER1_OVF_vect			_VECTOR(4)
 #define SIG_OVERFLOW1			_VECTOR(4)
 
 /* Timer/Counter0 Overflow */
+#define TIM0_OVF_vect_num		5
 #define TIM0_OVF_vect			_VECTOR(5)
+#define TIMER0_OVF_vect_num		5
+#define TIMER0_OVF_vect			_VECTOR(5)
 #define SIG_OVERFLOW0			_VECTOR(5)
 
 /* EEPROM Ready */
-#define EE_RDY_vect			_VECTOR(6)
+#define EE_RDY_vect_num			6
+#define EE_RDY_vect		    	_VECTOR(6)
 #define SIG_EEPROM_READY		_VECTOR(6)
 
 /* Analog comparator */
+#define ANA_COMP_vect_num		7
 #define ANA_COMP_vect			_VECTOR(7)
 #define SIG_COMPARATOR			_VECTOR(7)
 
 /* ADC Conversion ready */
-#define ADC_vect			_VECTOR(8)
-#define SIG_ADC				_VECTOR(8)
+#define ADC_vect_num    		8
+#define ADC_vect		    	_VECTOR(8)
+#define SIG_ADC				    _VECTOR(8)
 
 /* Timer/Counter1 Compare Match B */
+#define TIM1_COMPB_vect_num  	9
 #define TIM1_COMPB_vect			_VECTOR(9)
-#define SIG_OUTPUT_COMPARE1B		_VECTOR(9)
+#define TIMER1_COMPB_vect_num	9
+#define TIMER1_COMPB_vect   	_VECTOR(9)
+#define SIG_OUTPUT_COMPARE1B	_VECTOR(9)
 
 /* Timer/Counter0 Compare Match A */
+#define TIM0_COMPA_vect_num		10
 #define TIM0_COMPA_vect			_VECTOR(10)
-#define SIG_OUTPUT_COMPARE0A		_VECTOR(10)
+#define TIMER0_COMPA_vect_num	10
+#define TIMER0_COMPA_vect		_VECTOR(10)
+#define SIG_OUTPUT_COMPARE0A	_VECTOR(10)
 
 /* Timer/Counter0 Compare Match B */
+#define TIM0_COMPB_vect_num		11
 #define TIM0_COMPB_vect			_VECTOR(11)
-#define SIG_OUTPUT_COMPARE0B		_VECTOR(11)
+#define TIMER0_COMPB_vect_num	11
+#define TIMER0_COMPB_vect		_VECTOR(11)
+#define SIG_OUTPUT_COMPARE0B	_VECTOR(11)
 
 /* Watchdog Time-out */
-#define WDT_vect			_VECTOR(12)
-#define SIG_WATCHDOG_TIMEOUT		_VECTOR(12)
+#define WDT_vect_num			12
+#define WDT_vect				_VECTOR(12)
+#define SIG_WATCHDOG_TIMEOUT	_VECTOR(12)
 
 /* USI START */
+#define USI_START_vect_num		13
 #define USI_START_vect			_VECTOR(13)
 #define SIG_USI_START			_VECTOR(13)
 
 /* USI Overflow */
+#define USI_OVF_vect_num		14
 #define USI_OVF_vect			_VECTOR(14)
 #define SIG_USI_OVERFLOW		_VECTOR(14)
 
