@@ -28,7 +28,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: iousbxx6_7.h 2102 2010-03-16 22:52:39Z joerg_wunsch $ */
+/* $Id: iousbxx6_7.h 2225 2011-03-02 16:27:26Z arcanum $ */
 
 /* iousbxx6_7.h - definitions for AT90USB646, AT90USB647, AT90USB1286 
    and AT90USB1287 */
@@ -1162,114 +1162,151 @@
 /* Interrupt vectors */
 
 /* External Interrupt Request 0 */
-#define INT0_vect			_VECTOR(1)
+#define INT0_vect_num			1
+#define INT0_vect	    		_VECTOR(1)
 
 /* External Interrupt Request 1 */
-#define INT1_vect			_VECTOR(2)
+#define INT1_vect_num			2
+#define INT1_vect	    		_VECTOR(2)
 
 /* External Interrupt Request 2 */
-#define INT2_vect			_VECTOR(3)
+#define INT2_vect_num			3
+#define INT2_vect	    		_VECTOR(3)
 
 /* External Interrupt Request 3 */
-#define INT3_vect			_VECTOR(4)
+#define INT3_vect_num			4
+#define INT3_vect	    		_VECTOR(4)
 
 /* External Interrupt Request 4 */
-#define INT4_vect			_VECTOR(5)
+#define INT4_vect_num			5
+#define INT4_vect	    		_VECTOR(5)
 
 /* External Interrupt Request 5 */
-#define INT5_vect			_VECTOR(6)
+#define INT5_vect_num			6
+#define INT5_vect	    		_VECTOR(6)
 
 /* External Interrupt Request 6 */
-#define INT6_vect			_VECTOR(7)
+#define INT6_vect_num			7
+#define INT6_vect	    		_VECTOR(7)
 
 /* External Interrupt Request 7 */
-#define INT7_vect			_VECTOR(8)
+#define INT7_vect_num			8
+#define INT7_vect	    		_VECTOR(8)
 
 /* Pin Change Interrupt Request 0 */
-#define PCINT0_vect			_VECTOR(9)
+#define PCINT0_vect_num			9
+#define PCINT0_vect		    	_VECTOR(9)
 
 /* USB General Interrupt Request */
+#define USB_GEN_vect_num		10
 #define USB_GEN_vect			_VECTOR(10)
 
 /* USB Endpoint/Pipe Interrupt Communication Request */
+#define USB_COM_vect_num		11
 #define USB_COM_vect			_VECTOR(11)
 
 /* Watchdog Time-out Interrupt */
-#define WDT_vect			_VECTOR(12)
+#define WDT_vect_num			12
+#define WDT_vect	    		_VECTOR(12)
 
 /* Timer/Counter2 Compare Match A */
+#define TIMER2_COMPA_vect_num	13
 #define TIMER2_COMPA_vect		_VECTOR(13)
 
 /* Timer/Counter2 Compare Match B */
+#define TIMER2_COMPB_vect_num	14
 #define TIMER2_COMPB_vect		_VECTOR(14)
 
 /* Timer/Counter2 Overflow */
+#define TIMER2_OVF_vect_num		15
 #define TIMER2_OVF_vect			_VECTOR(15)
 
 /* Timer/Counter1 Capture Event */
+#define TIMER1_CAPT_vect_num	16
 #define TIMER1_CAPT_vect		_VECTOR(16)
 
 /* Timer/Counter1 Compare Match A */
+#define TIMER1_COMPA_vect_num	17
 #define TIMER1_COMPA_vect		_VECTOR(17)
 
 /* Timer/Counter1 Compare Match B */
+#define TIMER1_COMPB_vect_num	18
 #define TIMER1_COMPB_vect		_VECTOR(18)
 
 /* Timer/Counter1 Compare Match C */
+#define TIMER1_COMPC_vect_num	19
 #define TIMER1_COMPC_vect		_VECTOR(19)
 
 /* Timer/Counter1 Overflow */
+#define TIMER1_OVF_vect_num		20
 #define TIMER1_OVF_vect			_VECTOR(20)
 
 /* Timer/Counter0 Compare Match A */
+#define TIMER0_COMPA_vect_num	21
 #define TIMER0_COMPA_vect		_VECTOR(21)
 
 /* Timer/Counter0 Compare Match B */
+#define TIMER0_COMPB_vect_num	22
 #define TIMER0_COMPB_vect		_VECTOR(22)
 
 /* Timer/Counter0 Overflow */
+#define TIMER0_OVF_vect_num		23
 #define TIMER0_OVF_vect			_VECTOR(23)
 
 /* SPI Serial Transfer Complete */
+#define SPI_STC_vect_num		24
 #define SPI_STC_vect			_VECTOR(24)
 
 /* USART1, Rx Complete */
+#define USART1_RX_vect_num		25
 #define USART1_RX_vect			_VECTOR(25)
 
 /* USART1 Data register Empty */
+#define USART1_UDRE_vect_num    26
 #define USART1_UDRE_vect		_VECTOR(26)
 
 /* USART1, Tx Complete */
+#define USART1_TX_vect_num		27
 #define USART1_TX_vect			_VECTOR(27)
 
 /* Analog Comparator */
+#define ANALOG_COMP_vect_num	28
 #define ANALOG_COMP_vect		_VECTOR(28)
 
 /* ADC Conversion Complete */
-#define ADC_vect			_VECTOR(29)
+#define ADC_vect_num			29
+#define ADC_vect	    		_VECTOR(29)
 
 /* EEPROM Ready */
+#define EE_READY_vect_num		30
 #define EE_READY_vect			_VECTOR(30)
 
 /* Timer/Counter3 Capture Event */
+#define TIMER3_CAPT_vect_num	31
 #define TIMER3_CAPT_vect		_VECTOR(31)
 
 /* Timer/Counter3 Compare Match A */
+#define TIMER3_COMPA_vect_num	32
 #define TIMER3_COMPA_vect		_VECTOR(32)
 
 /* Timer/Counter3 Compare Match B */
+#define TIMER3_COMPB_vect_num	33
 #define TIMER3_COMPB_vect		_VECTOR(33)
 
 /* Timer/Counter3 Compare Match C */
+#define TIMER3_COMPC_vect_num	34
 #define TIMER3_COMPC_vect		_VECTOR(34)
 
 /* Timer/Counter3 Overflow */
+#define TIMER3_OVF_vect_num		35
 #define TIMER3_OVF_vect			_VECTOR(35)
 
 /* 2-wire Serial Interface */
-#define TWI_vect			_VECTOR(36)
+#define TWI_vect_num			_VECTOR(36)
+#define TWI_vect			    _VECTOR(36)
 
 /* Store Program Memory Read */
+#define SPM_READY_vect_num		37
 #define SPM_READY_vect			_VECTOR(37)
 
 #define _VECTORS_SIZE 152
