@@ -29,7 +29,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: wdt.h,v 1.44.2.33 2009/12/03 18:38:59 arcanum Exp $ */
+/* $Id: wdt.h 2211 2011-02-14 14:04:25Z aboyapati $ */
 
 /*
    avr/wdt.h - macros for AVR watchdog timer
@@ -134,10 +134,11 @@
 || defined(__AVR_ATxmega16D4__) \
 || defined(__AVR_ATxmega32A4__) \
 || defined(__AVR_ATxmega32D4__) \
-|| defined(__AVR_ATxmega64A1__) \
+|| defined(__AVR_ATxmega64A1U__) \
 || defined(__AVR_ATxmega64A3__) \
 || defined(__AVR_ATxmega64D3__) \
 || defined(__AVR_ATxmega128A1__) \
+|| defined(__AVR_ATxmega128A1U__) \
 || defined(__AVR_ATxmega128A3__) \
 || defined(__AVR_ATxmega128D3__) \
 || defined(__AVR_ATxmega192A3__) \
@@ -203,6 +204,7 @@ __asm__ __volatile__ ( \
 || defined(__AVR_ATmega16HVA__) \
 || defined(__AVR_ATmega16HVA2__) \
 || defined(__AVR_ATmega16HVB__) \
+|| defined(__AVR_ATmega16HVBREVB__) \
 || defined(__AVR_ATmega16M1__) \
 || defined(__AVR_ATmega16U2__) \
 || defined(__AVR_ATmega16U4__) \
@@ -213,16 +215,23 @@ __asm__ __volatile__ ( \
 || defined(__AVR_ATmega324P__) \
 || defined(__AVR_ATmega324PA__) \
 || defined(__AVR_ATmega325__) \
+|| defined(__AVR_ATmega325A__) \
+|| defined(__AVR_ATmega325P__) \
 || defined(__AVR_ATmega3250__) \
+|| defined(__AVR_ATmega3250A__) \
+|| defined(__AVR_ATmega3250P__) \
 || defined(__AVR_ATmega328__) \
 || defined(__AVR_ATmega328P__) \
 || defined(__AVR_ATmega329__) \
+|| defined(__AVR_ATmega329A__) \
 || defined(__AVR_ATmega329P__) \
 || defined(__AVR_ATmega329PA__) \
 || defined(__AVR_ATmega3290__) \
+|| defined(__AVR_ATmega3290A__) \
 || defined(__AVR_ATmega3290P__) \
 || defined(__AVR_ATmega32C1__) \
 || defined(__AVR_ATmega32HVB__) \
+|| defined(__AVR_ATmega32HVBREVB__) \
 || defined(__AVR_ATmega32M1__) \
 || defined(__AVR_ATmega32U2__) \
 || defined(__AVR_ATmega32U4__) \
@@ -397,7 +406,7 @@ __asm__ __volatile__ (  \
     See \c WDT0_15MS
     Note: This is only available on the 
     ATtiny2313, 
-    ATtiny24, ATtiny44, ATtiny84, 
+    ATtiny24, ATtiny44, ATtiny84, ATtiny84A,
     ATtiny25, ATtiny45, ATtiny85, 
     ATtiny261, ATtiny461, ATtiny861, 
     ATmega48, ATmega88, ATmega168,
@@ -418,7 +427,7 @@ __asm__ __volatile__ (  \
     See \c WDT0_15MS
     Note: This is only available on the 
     ATtiny2313, 
-    ATtiny24, ATtiny44, ATtiny84, 
+    ATtiny24, ATtiny44, ATtiny84, ATtiny84A,
     ATtiny25, ATtiny45, ATtiny85, 
     ATtiny261, ATtiny461, ATtiny861, 
     ATmega48, ATmega88, ATmega168,
